import { HTTPClient } from "koajax";
import { TypeKeys } from "web-utility";
export function splitList<T>(array: T[], unitLength: number): T[][];
export const service: HTTPClient<import("koajax").Context>;
export abstract class BaseModel {
    downloading: number;
    uploading: number;
    clear(): this;
}
export function toggle<T extends BaseModel>(property: TypeKeys<T, boolean | number>): (target: any, key: string, meta: PropertyDescriptor) => void;
export type IDType = number | string;
export type DataObject = Record<string, any>;
export type NewData<T extends DataObject> = {
    [K in Exclude<keyof T, TypeKeys<T, DataObject>>]?: T[K];
} & {
    [K in TypeKeys<T, DataObject>]?: IDType;
};
export abstract class BaseListModel<D extends DataObject> extends BaseModel {
    abstract baseURI: string;
    currentOne: D;
    static createNested(parentId: IDType): BaseListModel<{}>;
    clear(): this;
    updateOne(data: NewData<D>, id?: IDType): Promise<D>;
    getOne(id: IDType): Promise<D>;
    removeOne(id: IDType): Promise<void>;
}
export type Filter<T extends DataObject> = {
    pageSize?: number;
    pageIndex?: number;
} & {
    [K in TypeKeys<T, DataObject>]?: IDType;
};
export abstract class ListModel<D extends DataObject, F extends Filter<D> = Filter<D>> extends BaseListModel<D> {
    pageIndex: number;
    pageSize: number;
    filter: F;
    noMore: boolean;
    totalCount: number;
    pageList: D[][];
    get currentPage(): D[];
    get allItems(): any[];
    constructor();
    clear(): this;
    turnTo(pageIndex: number, pageSize?: number): this;
    protected abstract loadPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
    } & Partial<Pick<ListModel<D, F>, 'totalCount'>>>;
    protected loadNewPage(pageIndex: number, pageSize: number, filter: F): Promise<{
        pageData: D[];
        totalCount: number;
    }>;
    protected flushPage(pageIndex: number, pageSize: number, pageData: D[]): D[];
    getList(filter?: F, pageIndex?: number, pageSize?: number): Promise<D[]>;
}
export abstract class CacheListModel<D extends DataObject, F extends Filter<D> = Filter<D>> extends ListModel<D, F> {
    protected pendingList: ReturnType<ListModel<D, F>['loadPage']>[];
    clear(): this;
    getList(filter?: F, pageIndex?: number, pageSize?: number): Promise<D[]>;
}

//# sourceMappingURL=index.d.ts.map
